'use strict';

// This module manages the dialogs etc. we need.

/* global IMatchTranslate */
function MapModals() {
  var self = this;

  var progressVisible = false;
  var hasModal = false;

  // Closes open modals or progress overlays.
  // No callbacks (e.g. for YesNo) will be called!
  self.closeAll = function() {
    if (hasModal) {
      hasModal = false;
      $('#imm-modal').modal('hide');
    }

    self.closeProgressOverlay();
  };

  // Display a OK box with the specified title and text.
  self.showMessageBoxOK = function(title, text) {
    self.showMessageBox('mb-ok-tpl.html', null, null, function() {
      $('#modal-headline').html(title);
      $('#modal-content').html(text);
    });
  };

  // Display a Yes/No box with the specified title and text.
  self.showMessageBoxYesNo = function(title, text, callbackYes, callbackNo) {
    self.showMessageBox(
      'mb-yesno-tpl.html',
      callbackYes,
      callbackNo,
      function() {
        $('#modal-headline').html(title);
        $('#modal-content').html(text);
      }
    );
  };

  self.showMessageBox = function(templateFileName, onOK, onCancel, callback) {
    $.get('modals/' + templateFileName, function(data) {
      var ok = false;

      // Add template to DOM
      $('#app-container').append(data);

      // Translate the modal and all children
      IMatchTranslate.translateElement('#imm-modal');

      if (callback) {
        callback($('#imm-modal'));
      }

      hasModal = true;

      // Open the modal
      $('#imm-modal').modal({});

      // Remove the HTML template when the modal is closed.
      // Call the onCancel callback of the modal was not closed by the OK button.
      $('#imm-modal').on('hidden.bs.modal', function() {
        // var e = $('#imm-modal');
        hasModal = false;
        $('#imm-modal').remove();
        if (!ok) {
          if (onCancel) onCancel();
        }
      });

      // Handle the OK button.
      // Close the modal and call the onOK callback.
      $('#imm-ok').click(function() {
        ok = true;
        hasModal = false;
        $('#imm-modal').modal('hide');
        if (onOK) onOK();
      });
    });
  };

  // Display 10 full-size overlay with a headline, text and progress bar.
  // createCallback is called once the overlay has been added to the DOM.
  // abortCallback is called when the user clicks on the abort button (only when showAbort is true)
  self.showProgressOverlay = function(
    showAbort,
    createCallback,
    abortCallback
  ) {
    $.get('modals/modal-progress-tpl.html', function(data) {
      progressVisible = true;

      $('#imm-progress-pbar').css('width', '0%');

      // Add template to DOM
      $('#app-container').append(data);

      // Translate the modal and all children
      IMatchTranslate.translateElement('#imm-modal');

      if (showAbort) {
        $('#imm-progress-abort').show();
        $('#imm-progress-abort').removeClass('disabled');
      }

      if (createCallback) {
        createCallback($('#imm-modal'));
      }

      // Open the modal
      $('#imm-modal').modal({});

      // Remove the HTML template when the modal is closed.
      // Call the onCancel callback of the modal was not closed by the OK button.
      $('#imm-modal').on('hidden.bs.modal', function() {
        // var e = $('#imm-modal');
        $('#imm-modal').remove();
      });

      // Handle the OK button.
      // Close the modal and call the onOK callback.
      $('#imm-progress-abort').click(function() {
        if (showAbort) {
          $('#imm-modal').modal('hide');
          progressVisible = false;
          if (abortCallback) abortCallback();
        }
      });
    });
  };

  // Set a new percentage between 0 and 100.
  // Optional set a new title and/or text
  self.setProgressOverlayPercentage = function(perc, title, text) {
    if (progressVisible) {
      var p = Math.max(0, Math.min(100, perc));
      $('#imm-progress-pbar').css('width', p + '%');
      $('#imm-progress-pbar').text(Math.floor(p) + '%');

      if (title !== undefined) {
        $('#modal-headline').text(title);
      }
      if (text !== undefined) {
        $('#modal-content').text(text);
      }
    }
  };

  // Close the current progress overlay if there is one
  self.closeProgressOverlay = function() {
    if (progressVisible) {
      progressVisible = false;
      $('#imm-modal').modal('hide');
    }
  };
}
